@@ -126,8 +126,7 @@ class Placeholder(models.Model):
         """
         return [field.model for field in self._get_attached_fields()]
 
-    @property
-    def page(self):
+    def page_getter(self):
         if not hasattr(self, '_page'):
             from cms.models.pagemodel import Page
             try:
@@ -136,10 +135,11 @@ class Placeholder(models.Model):
                 self._page = None
         return self._page
 
-    @page.setter
-    def page(self, value):
+    def page_setter(self, value):
         self._page = value
 
+    page = property(page_getter, page_setter)
+
     def get_plugins_list(self):
         return list(self.get_plugins())
 
