@@ -1,15 +1,11 @@
-(function ($) {
-/**
- * @requires:	Classy, jQuery, jQuery.ui.core, jQuery.ui.draggable, jQuery.ui.droppable
- */
-
 /*##################################################|*/
 /* #CMS.PLACEHOLDERS# */
-jQuery(document).ready(function ($) {
-	/**
+CMS.$(document).ready(function ($) {
+	// assign correct jquery to $ namespace
+	$ = CMS.$ || $;
+
+	/*!
 	 * Placeholders
-	 * @version: 1.0.0
-	 * @description: Handles placeholders when in editmode and adds "lightbox" to toolbar
 	 * @public_methods:
 	 *	- CMS.API.Placeholder.addPlugin(obj, url);
 	 *	- CMS.API.Placeholder.editPlugin(placeholder_id, plugin_id);
@@ -32,8 +28,6 @@ jQuery(document).ready(function ($) {
 		},
 
 		initialize: function (container, options) {
-			// save reference to this class
-			var that = this;
 			// merge argument options with internal options
 			this.options = $.extend(this.options, options);
 			
@@ -147,7 +141,7 @@ jQuery(document).ready(function ($) {
 						if (needs_collapsing && ! CMS.API.Toolbar.isToolbarHidden()){
 							CMS.API.Toolbar.toggleToolbar();
 						}
-					})
+					});
 				var cancel = $(this).contents().find('input[name^="_cancel"]');
 					cancel.bind('click', function (e) {
 						e.preventDefault();
@@ -323,10 +317,10 @@ jQuery(document).ready(function ($) {
 				var els = $('.cms_placeholder[class$="cms_placeholder::' + slot + '"]');
 				var length = els.length;
 
-				if(els.length === 0) {
+				if(length === 0) {
 					plugin.insertAfter($('.cms_placeholder-bar[class$="cms_placeholder_slot::' + slot + '"]'));
 				} else {
-					plugin.insertAfter($(els.toArray()[els.length-1]));
+					plugin.insertAfter($(els.toArray()[length-1]));
 				}
 
 				// close overlay
@@ -472,7 +466,7 @@ jQuery(document).ready(function ($) {
 			// change data information
 			this.dim.data('dimmed', false);
 			// hide dim
-			this.dim.css('opcaity', 0.6).stop().fadeOut();
+			this.dim.css('opacity', 0.6).stop().fadeOut();
 			// remove dim event
 			this.dim.unbind('click');
 		}
@@ -597,6 +591,4 @@ jQuery(document).ready(function ($) {
 
 	});
 
-});
-
-})(jQuery);
+});
\ No newline at end of file
